﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

using PlatformSDKSample;

namespace SynchronousPlayback
{
    public partial class ViewCell : Form
    {
        IntPtr hChannel = IntPtr.Zero;
        public ViewCell()
        {
            InitializeComponent();
        }
        public IntPtr CreateSyncChannel(ref TCreateChannelInfo info)
        {
            PlatformSDK.TStreamInfo streamInfo = new PlatformSDK.TStreamInfo();

            streamInfo.streamSource = PlatformSDK.EStreamSource.VAST;
            streamInfo.streamMode = PlatformSDK.EStreamMode.normalStream;
            streamInfo.timeType = PlatformSDK.ETimeType.recordingTime;
            streamInfo.serverIP = info.serverIP;
            streamInfo.serverUserName = info.serverUserName;
            streamInfo.serverPassword = info.serverPassword;
            streamInfo.serverPort = info.serverPort;
            streamInfo.cameraID = info.cameraID;
            streamInfo.pfStreamStatusCB = null;
            streamInfo.pfStreamDataCB = null;
            streamInfo.pfPCMDataCB = null;
            streamInfo.pfYV12DataCB = null;
            streamInfo.pfVideoDecodeCB = null;
            streamInfo.hDisplayWindow = panel1.Handle;
            streamInfo.startTime = info.startTime;
            streamInfo.endTime = info.endTime;
            streamInfo.streamIndex = info.streamIndex;
            streamInfo.streamInitStatus = PlatformSDK.EStreamInitStatus.play;
            streamInfo.timeKind = PlatformSDK.ETimeKind.UTC;
            streamInfo.capVersion = info.capVersion;
            streamInfo.useSSL = info.useSSL;
            streamInfo.videoDisplayMode = PlatformSDK.EVideoDisplayMode.fillViewCell;
            streamInfo.playbackMode = PlatformSDK.EPlaybackMode.synchronous;

            int ret = PlatformSDK.CreateNetFileChannel(ref hChannel, ref streamInfo);
            EventLog.Write("PlatformSDK.CreateNetFileChannel Ret = {0:X}", ret);

            SetDisplayInfo();

            return hChannel;
        }

        void SetDisplayInfo()
        {
            PlatformSDK.TStreamingDisplayInfo info = new PlatformSDK.TStreamingDisplayInfo();

            info.showFrameTime = true;
            info.showMillisecond = true;
            info.showTextShadow = true;
            info.opaqueBackground = true;
            info.timeSource = PlatformSDK.ETimeSource.recordingTime;
            info.timeKind = PlatformSDK.ETimeKind.local;
            info.ARGBTextColor = (255 << 16) | (255 << 8) | 255;
            info.ARGBBackgroundColor = (0 << 16) | (0 << 8) | 0;
            info.fontSize = 22;

            int ret = PlatformSDK.SetDisplayInfo(hChannel, ref info);
            EventLog.Write("SetDisplayInfo: {0:X}", ret);
        }

        private static readonly DateTime dateTime1970 = new DateTime(1970, 1, 1);
        uint UtcDateTime2time_t(DateTime datetime)
        {
            TimeSpan diff = datetime.ToUniversalTime() - dateTime1970;
            return (uint)(diff.TotalSeconds);
        }

        private void button1_Click(object sender, EventArgs e)
        {
            uint startTime = UtcDateTime2time_t(startTimePicker.Value);
            uint endTime = UtcDateTime2time_t(endTimePicker.Value);

            Program.seek(startTime, endTime);
        }
    }
}
